@@ -38,7 +38,7 @@ no warnings;
 
 our @EXPORT = qw( newretrieve newreport get_files );
 
-$VERSION = '0.109';
+$VERSION = '0.111';
 $ABSTRACT = 'Sim::OPT::Report is the module used by Sim::OPT to retrieve simulation results.';
 
 #########################################################################################
@@ -1172,7 +1172,7 @@ sub newreport # This function retrieves the results of interest from the texts f
               {
                 my $thisline = $line;
                 $thisline =~ s/^(\s+)//;
-                $thisline =~ s/^ +)//;
+                $thisline =~ s/(^ +)//;
 
                 if ( $thisline =~ /^$textpattern/ )
                 {
